@@ -2,7 +2,7 @@ from datetime import datetime
 from enum import Enum
 from typing import List, Optional
 
-from poe_client.schemas import CamelModel
+from poe_client.schemas import Model
 from poe_client.schemas.account import Account
 from poe_client.schemas.character import Character
 
@@ -15,7 +15,7 @@ class LeagueType(Enum):
     season = "season"
 
 
-class LeagueRule(CamelModel):
+class LeagueRule(Model):
     """Dataclass to describe a LeagueRule of a League."""
 
     id: str
@@ -23,7 +23,7 @@ class LeagueRule(CamelModel):
     description: Optional[str]
 
 
-class League(CamelModel):
+class League(Model):
     """Dataclass to describe a League."""
 
     id: str
@@ -40,19 +40,44 @@ class League(CamelModel):
     delve_event: bool = False
 
 
-class LadderEntry(CamelModel):
+class ArchnemesisProgress(Model):
+    """Dataclass to describe the progress field during Archnemesis league."""
+
+    maven_enraged_defeated: bool
+    cleansing_boss_defeated: bool
+    consume_boss_defeated: bool
+
+
+class LadderEntry(Model):
     """Dataclass to describe character's LadderEntry."""
 
     rank: int
     dead: bool = False
     retired: bool = False
-    online: bool = False
+
+    # Deprecated
+    online: Optional[bool] = False
     public: bool = False
     character: Character
     account: Optional[Account]
+    progress: Optional[ArchnemesisProgress]
 
 
-class Ladder(CamelModel):
+class Ladder(Model):
+    """Dataclass to describe a Ladder in a league."""
+
     total: int
     cached_since: Optional[datetime]
     entries: List[LadderEntry]
+
+
+class AtlasPassiveHashes(Model):
+    """Datacass to describe the Atlas Passive field of a LeagueAccount"""
+
+    hashes: List[int]
+
+
+class LeagueAccount(Model):
+    """Dataclass to describe a LeagueAccount"""
+
+    atlas_passives: Optional[AtlasPassiveHashes]
